.dijitRtl .nihilo .dijitTab {margin-right:0; margin-left:2px;}.dijitRtl .nihilo .dijitTabContainerTopStrip,.dijitRtl .nihilo .dijitTabContainerBottomStrip {padding-right: 3px; padding-left: 0px;}.dijitRtl .nihilo .dijitTabContainerTop-tabs {padding-left: auto; padding-right: 3px;}.dijitRtl .nihilo .dijitTabContainerBottom-tabs {padding-left: auto; padding-right: 3px;}.dijitRtl .nihilo .dijitTabInnerDiv {padding-left: 3px; padding-right: 4px;}.dijitRtl .nihilo .dijitTabPaneWrapper {#zoom: 1;}.dj_ie-rtl .nihilo .dijitTabContainerLeft-tabs {margin-left: 0px !important;}.dj_ie-rtl .nihilo .dijitTabContainerRight-tabs {margin-right: 0px !important;}.dijitRtl .nihilo .dijitTabContainerLeft-tabs .dijitTab,.dijitRtl .nihilo .dijitTabContainerRight-tabs .dijitTab {margin-left:0px;}.dj_ie .nihilo .dijitTab .dijitTabInnerDiv{width : 1%;}